====================================
User Guide
====================================

.. from gemviz
    .. _fig.mdaviz_gui:

    .. figure:: _static/mdaviz_gui.png
        :alt: fig.mdaviz_gui
        :width: 80%

Command-line
------------

todo

.. todo:
    Export
    ------

    * data
    * plot script (such as SVG)
    * plot image
